@@ -1,8 +1,7 @@
 import PropTypes from "prop-types";
-import * as React from "react";
+import React from "react";
 import Map from "./components/Map";
-import template from "../../../demo/example-data/welllayer_template.json";
-import colorTables from "../../../demo/example-data/color-tables.json";
+import colorTables from "@emerson-eps/color-tables/src/component/color-tables.json";
 
 DeckGLMap.defaultProps = {
     coords: {
@@ -22,9 +21,11 @@ DeckGLMap.defaultProps = {
         horizontal: true,
     },
     zoom: -3,
-    view3D: false,
+    views: {
+        layout: [1, 1],
+        viewport: [{ id: "main-view", show3D: false, layerIds: [] }],
+    },
     colorTables: colorTables,
-    template: template,
 };
 
 function DeckGLMap({
@@ -33,11 +34,10 @@ function DeckGLMap({
     layers,
     bounds,
     zoom,
-    view3D,
+    views,
     coords,
     scale,
     legend,
-    template,
     colorTables,
     coordinateUnit,
     editedData,
@@ -77,11 +77,10 @@ function DeckGLMap({
             layers={layers}
             bounds={bounds}
             zoom={zoom}
-            view3D={view3D}
+            views={views}
             coords={coords}
             scale={scale}
             legend={legend}
-            template={template}
             colorTables={colorTables}
             coordinateUnit={coordinateUnit}
             editedData={layerEditedData}
@@ -118,9 +117,37 @@ DeckGLMap.propTypes = {
     zoom: PropTypes.number,
 
     /**
-     * If true, displays map in 3D view, default is 2D view
+     * Views configuration for map. If not specified, all the layers will be
+     * displayed in a single 2D viewport
      */
-    view3D: PropTypes.bool,
+    views: PropTypes.shape({
+        /**
+         * Layout for viewport in specified as [row, column]
+         */
+        layout: PropTypes.arrayOf(PropTypes.number),
+
+        /**
+         * Layers configuration for multiple viewport
+         */
+        viewports: PropTypes.arrayOf(
+            PropTypes.shape({
+                /**
+                 * Viewport id
+                 */
+                id: PropTypes.string,
+
+                /**
+                 * If true, displays map in 3D view, default is 2D view
+                 */
+                show3D: PropTypes.bool,
+
+                /**
+                 * Layers to be displayed on viewport
+                 */
+                layerIds: PropTypes.arrayOf(PropTypes.string),
+            })
+        ),
+    }),
 
     /** List of JSON object containing layer specific data.
      * Each JSON object will consist of layer type with key as "@@type" and
@@ -210,10 +237,6 @@ DeckGLMap.propTypes = {
      * Prop containing color table data
      */
     colorTables: PropTypes.arrayOf(PropTypes.object),
-    /**
-     * Prop containing color template data
-     */
-    template: PropTypes.arrayOf(PropTypes.object),
 };
 
 export default DeckGLMap;
