@@ -10,8 +10,11 @@ import {
     PropertyMapPickInfo,
     ValueDecoder,
 } from "../utils/propertyMapTools";
-
+import { getModelMatrix } from "../utils/layerTools";
+import { layersDefaultProps } from "../layersDefaultProps";
 import fsColormap from "!!raw-loader!./colormap.fs.glsl";
+import { DeckGLLayerContext } from "../../components/DeckGLWrapper";
+import { colorTablesArray, rgbValues } from "@emerson-eps/color-tables/";
 
 const DEFAULT_TEXTURE_PARAMETERS = {
     [GL.TEXTURE_MIN_FILTER]: GL.LINEAR_MIPMAP_LINEAR,
@@ -20,6 +23,29 @@ const DEFAULT_TEXTURE_PARAMETERS = {
     [GL.TEXTURE_WRAP_T]: GL.CLAMP_TO_EDGE,
 };
 
+function getImageData(colorMapName: string, colorTables: colorTablesArray) {
+    const data = new Uint8Array(256 * 3);
+
+    for (let i = 0; i < 256; i++) {
+        const value = i / 255.0;
+        const rgb = rgbValues(value, colorMapName, colorTables);
+        let color: number[] = [];
+        if (rgb != undefined) {
+            if (Array.isArray(rgb)) {
+                color = rgb;
+            } else {
+                color = [rgb.r, rgb.g, rgb.b];
+            }
+        }
+
+        data[3 * i + 0] = color[0];
+        data[3 * i + 1] = color[1];
+        data[3 * i + 2] = color[2];
+    }
+
+    return data;
+}
+
 // Most props are inherited from DeckGL's BitmapLayer. For a full list, see
 // https://deck.gl/docs/api-reference/layers/bitmap-layer
 //
@@ -39,10 +65,8 @@ const DEFAULT_TEXTURE_PARAMETERS = {
 // > 16mil possible values for any property value range.
 // We also support property maps with an alpha channel. See colormap.fs.glsl for more details.
 export interface ColormapLayerProps<D> extends BitmapLayerProps<D> {
-    // Image containing the colors that will be applied to te values.
-    // e.g.: https://cdn.jsdelivr.net/gh/kylebarron/deck.gl-raster/assets/colormaps/plasma.png
-    // No size requirements. Alpha channel (opacity) supported.
-    colormap: unknown;
+    // Name of color map.
+    colorMapName: string;
 
     // Min and max property values.
     valueRange: [number, number];
@@ -52,24 +76,14 @@ export interface ColormapLayerProps<D> extends BitmapLayerProps<D> {
 
     // See ValueDecoder in propertyMapTools.ts
     valueDecoder: ValueDecoder;
+
+    // Rotates image around bounds upper left corner counterclockwise in degrees.
+    rotDeg: number;
 }
 
-const defaultProps = {
-    name: "Property map",
-    colormap: { type: "object", value: null, async: true },
-    valueRange: { type: "array" },
-    colorMapRange: { type: "array" },
-    valueDecoder: {
-        type: "object",
-        value: {
-            rgbScaler: [1, 1, 1],
-            // By default, scale the [0, 256*256*256-1] decoded values to [0, 1]
-            floatScaler: 1.0 / (256.0 * 256.0 * 256.0 - 1.0),
-            offset: 0,
-            step: 0,
-        },
-    },
-};
+const defaultProps = layersDefaultProps[
+    "ColormapLayer"
+] as ColormapLayerProps<unknown>;
 
 export default class ColormapLayer extends BitmapLayer<
     unknown,
@@ -83,9 +97,14 @@ export default class ColormapLayer extends BitmapLayer<
             valueDecoder: {
                 // The prop objects are not merged with the defaultProps by default.
                 // See https://github.com/facebook/react/issues/2568
-                ...defaultProps.valueDecoder.value,
+                ...defaultProps.valueDecoder,
                 ...moduleParameters.valueDecoder,
             },
+            modelMatrix: getModelMatrix(
+                this.props.rotDeg,
+                this.props.bounds[0] as number, // Rotate around upper left corner of bounds
+                this.props.bounds[3] as number
+            ),
         };
         super.setModuleParameters(mergedModuleParams);
 
@@ -102,7 +121,14 @@ export default class ColormapLayer extends BitmapLayer<
                 ...uniforms,
                 // Send the colormap texture to the shader.
                 colormap: new Texture2D(context.gl, {
-                    data: this.props.colormap,
+                    width: 256,
+                    height: 1,
+                    format: GL.RGB,
+                    data: getImageData(
+                        this.props.colorMapName,
+                        (this.context as DeckGLLayerContext).userData
+                            .colorTables
+                    ),
                     parameters: DEFAULT_TEXTURE_PARAMETERS,
                 }),
                 valueRangeMin,
@@ -131,7 +157,7 @@ export default class ColormapLayer extends BitmapLayer<
         }
 
         const mergedDecoder = {
-            ...defaultProps.valueDecoder.value,
+            ...defaultProps.valueDecoder,
             ...this.props.valueDecoder,
         };
         // The picked color is the one in raw image, not the one after colormapping.
