@@ -9,8 +9,6 @@ import {
 import { Track, GraphTrack } from "@equinor/videx-wellog";
 import { Plot } from "@equinor/videx-wellog";
 
-import { ScaleTrackOptions } from "@equinor/videx-wellog/dist/tracks/scale/interfaces";
-
 import {
     OverlayClickEvent,
     OverlayMouseMoveEvent,
@@ -18,7 +16,7 @@ import {
     OverlayRescaleEvent,
 } from "@equinor/videx-wellog/dist/ui/interfaces";
 
-import "./styles.scss";
+import "!vue-style-loader!css-loader!sass-loader!./styles.scss";
 
 import { select } from "d3";
 
@@ -29,9 +27,11 @@ import { Template } from "./WellLogTemplateTypes";
 import { ColorTable } from "./ColorTableTypes";
 
 import { createTracks } from "../utils/tracks";
-import { getScaleTrackNum, isScaleTrack } from "../utils/tracks";
+import { getScaleTrackNum } from "../utils/tracks";
 import { AxesInfo } from "../utils/tracks";
 import { ExtPlotOptions } from "../utils/tracks";
+import { getTrackTemplate } from "../utils/tracks";
+import { isScaleTrack } from "../utils/tracks";
 
 import {
     addOrEditGraphTrack,
@@ -55,6 +55,8 @@ import {
     scrollTracksTo,
     isTrackSelected,
     selectTrack,
+    getSelectTrackIndeces,
+    restoreSelectTracks,
 } from "../utils/log-viewer";
 
 function showSelection(
@@ -189,10 +191,7 @@ function addReadoutOverlay(instance: LogViewer, parent: WellLogView) {
                 event.target.style.visibility = "visible";
             }
 
-            const x2 = (
-                caller.scaleHandler as InterpolatedScaleHandler
-            ).interpolator.reverse(value);
-            parent.onMouseMove(value, x2);
+            parent.onMouseMove(value);
         },
         onMouseExit: (event: OverlayMouseExitEvent): void => {
             if (event.target) event.target.style.visibility = "hidden";
@@ -289,6 +288,14 @@ function addPinnedValueOverlay(instance: LogViewer, parent: WellLogView) {
         .style("position", "absolute");
 }
 
+function initOverlay(instance: LogViewer, parent: WellLogView) {
+    instance.overlay.elm.style("overflow", "hidden"); // to clip content selection
+
+    addReadoutOverlay(instance, parent);
+    addRubberbandOverlay(instance, parent);
+    addPinnedValueOverlay(instance, parent);
+}
+
 function createInterpolator(from: Float32Array, to: Float32Array) {
     // 'from' array could be non monotonous (TVD) so could not use binary search
 
@@ -340,44 +347,6 @@ function createScaleHandler(
     return new InterpolatedScaleHandler(interpolator);
 }
 
-function getValue(
-    x: number,
-    data: [],
-    type: string
-): number /*|string for discrete?*/ {
-    let v = Number.NaN;
-    if (Number.isFinite(x)) {
-        const n = data.length;
-        for (let i = 0; i < n; i++) {
-            const row = data[i];
-            if (row[0] == null) continue;
-            if (row[1] == null) continue;
-            if (x < row[0]) {
-                if (!i) break;
-                else {
-                    const rowPrev = data[i - 1];
-                    if (rowPrev[0] == null || rowPrev[1] == null) break;
-                    if (type === "linestep") {
-                        v = row[1]; //!! not rowPrev[1] !!
-                    } else {
-                        const d = row[0] - rowPrev[0];
-                        const f = x - rowPrev[0];
-                        if (type === "dot") {
-                            v = f < d * 0.5 ? rowPrev[1] : row[1];
-                        } else {
-                            // "line", "area", "gradientfill"
-                            const mul = d ? (row[1] - rowPrev[1]) / d : 1.0;
-                            v = f * mul + rowPrev[1];
-                        }
-                    }
-                }
-                break;
-            }
-        }
-    }
-    return v;
-}
-
 function setTracksToController(
     logController: LogViewer,
     axes: AxesInfo,
@@ -475,7 +444,10 @@ function addPlot(
     );
 }
 
-function fillTemplatePlot(plot: Plot): TemplatePlot {
+function fillPlotTemplate(
+    templateTrack: TemplateTrack,
+    plot: Plot
+): TemplatePlot {
     const options = plot.options as ExtPlotOptions;
     const optionsDifferential = plot.options as DifferentialPlotOptions; // DifferentialPlot - 2 series!
     const options1 = optionsDifferential.serie1;
@@ -486,10 +458,13 @@ function fillTemplatePlot(plot: Plot): TemplatePlot {
     const legend1 = legendDifferential.serie1;
     const legend2 = legendDifferential.serie2;
 
+    const scale =
+        templateTrack?.scale !== options.scale ? options.scale : undefined;
+
     return {
-        style: "", // No style for this full Plot options.
+        style: undefined, // No style for this full Plot options.
         type: getPlotType(plot),
-        scale: options.scale,
+        scale: scale == "log" || scale == "linear" ? scale : undefined,
         name: (legend1 && legend1.label ? legend1.label : legend.label) || "",
         name2: legend2 && legend2.label ? legend2.label : "",
         color: (options1 ? options1.color : options.color) || "",
@@ -501,6 +476,8 @@ function fillTemplatePlot(plot: Plot): TemplatePlot {
         inverseColorTable: options.inverseColorTable
             ? options.inverseColorTable.name
             : "",
+        colorScale: options.colorScale,
+        inverseColorScale: options.inverseColorScale,
     };
 }
 
@@ -508,39 +485,29 @@ function editPlot(
     parent: HTMLElement,
     wellLogView: WellLogView,
     track: Track,
-    plot: Plot
+    templatePlot: TemplatePlot,
+    onOK: (templatePlot: TemplatePlot) => void
 ): void {
     const el: HTMLElement = document.createElement("div");
     el.style.width = "10px";
     el.style.height = "13px";
     parent.appendChild(el);
 
-    const templatePlot = fillTemplatePlot(plot);
-
     ReactDOM.render(
         <PlotPropertiesDialog
             templatePlot={templatePlot}
             wellLogView={wellLogView}
             track={track}
-            onOK={wellLogView._editTrackPlot.bind(wellLogView, track, plot)}
+            onOK={onOK}
         />,
         el
     );
 }
 
-function fillTemplateTrack(track: Track): TemplateTrack {
-    const options = track.options;
-
-    return {
-        title: options.label ? options.label : "",
-        plots: [],
-    };
-}
-
 export function addTrack(
     parent: HTMLElement,
     wellLogView: WellLogView,
-    trackCurrent: Track
+    onOK: (templateTrack: TemplateTrack) => void
 ): void {
     const el: HTMLElement = document.createElement("div");
     el.style.width = "10px";
@@ -548,10 +515,7 @@ export function addTrack(
     parent.appendChild(el);
 
     ReactDOM.render(
-        <TrackPropertiesDialog
-            wellLogView={wellLogView}
-            onOK={wellLogView._addTrack.bind(wellLogView, trackCurrent)}
-        />,
+        <TrackPropertiesDialog wellLogView={wellLogView} onOK={onOK} />,
         el
     );
 }
@@ -559,112 +523,24 @@ export function addTrack(
 export function editTrack(
     parent: HTMLElement,
     wellLogView: WellLogView,
-    track: Track
+    templateTrack: TemplateTrack,
+    onOK: (templateTrack: TemplateTrack) => void
 ): void {
     const el: HTMLElement = document.createElement("div");
     el.style.width = "10px";
     el.style.height = "13px";
     parent.appendChild(el);
 
-    const templateTrack = fillTemplateTrack(track);
-
     ReactDOM.render(
         <TrackPropertiesDialog
             templateTrack={templateTrack}
             wellLogView={wellLogView}
-            onOK={wellLogView._editTrack.bind(wellLogView, track)}
+            onOK={onOK}
         />,
         el
     );
 }
 
-function fillInfos(
-    x: number,
-    x2: number,
-    tracks: Track[],
-    iFrom: number,
-    iTo: number
-): Info[] {
-    const infos: Info[] = [];
-    let iPlot = 0;
-    let bSeparatorCreated = false;
-    let iTrack = 0;
-    for (const track of tracks) {
-        const bScaleTrack = isScaleTrack(track);
-        const visible = (iFrom <= iTrack && iTrack < iTo) || bScaleTrack;
-        if (visible) {
-            if (!bScaleTrack) {
-                if (!bSeparatorCreated) {
-                    // Add separator line
-                    infos.push({
-                        color: "", // dummy value
-                        value: Number.NaN, // dummy value
-                        type: "separator",
-                        track_id: track.id,
-                    });
-                    bSeparatorCreated = true;
-                }
-                for (const plot of (track as GraphTrack).plots) {
-                    const type = getPlotType(plot);
-                    let data = plot.data;
-                    if (type === "differential") data = plot.data[0]; // DifferentialPlot has 2 arrays of data pairs
-
-                    const options = plot.options as ExtPlotOptions;
-                    const optionsDifferential =
-                        plot.options as DifferentialPlotOptions; // DifferentialPlot - 2 series!
-                    const options1 = optionsDifferential.serie1;
-                    const options2 = optionsDifferential.serie2;
-
-                    const legend = options.legendInfo();
-                    const legendDifferential =
-                        legend as DifferentialPlotLegendInfo; // DifferentialPlot - 2 series!
-                    const legend1 = legendDifferential.serie1;
-                    const legend2 = legendDifferential.serie2;
-
-                    infos.push({
-                        name: legend1 ? legend1.label : legend.label,
-                        units: legend1 ? legend1.unit : legend.unit,
-                        color:
-                            (options1 ? options1.color : options.color) || "",
-                        value: getValue(x, data, type),
-                        type: type,
-                        track_id: track.id,
-                    });
-                    iPlot++;
-
-                    if (type === "differential") {
-                        data = plot.data[1];
-                        infos.push({
-                            name: legend2.label,
-                            units: legend2.unit,
-                            color:
-                                (options2 ? options2.color : options.color) ||
-                                "",
-                            value: getValue(x, data, type),
-                            type: type,
-                            track_id: "_" + track.id,
-                        });
-                        iPlot++;
-                    }
-                }
-            } else {
-                const _x = iPlot == 0 ? x : x2;
-                infos.push({
-                    name: track.options.abbr,
-                    units: (track.options as ScaleTrackOptions)["units"],
-                    color: iPlot == 0 ? "black" : "grey", //??
-                    value: _x,
-                    type: "", // "scale"
-                    track_id: track.id,
-                });
-                iPlot++;
-            }
-        }
-        if (!bScaleTrack) iTrack++;
-    }
-    return infos;
-}
-
 export interface TrackMouseEvent {
     track: Track;
     type: /*string, */ "click" | "contextmenu" | "dblclick";
@@ -690,6 +566,8 @@ export interface WellLogController {
     getTrackScrollPos(): number;
     getTrackScrollPosMax(): number;
     getTrackZoom(): number;
+
+    getTemplate(): Template;
 }
 
 import { Info } from "./InfoTypes";
@@ -704,20 +582,23 @@ interface Props {
     axisTitles: Record<string, string>;
     axisMnemos: Record<string, string[]>;
 
-    maxTrackNum?: number; // default is horizontal ? 3: 5
+    maxVisibleTrackNum?: number; // default is horizontal ? 3: 5
     maxContentZoom?: number; // default is 256
 
-    // current view position:
-    scrollTrackPos?: number; // the first track number
-
     // callbacks:
     onCreateController?: (controller: WellLogController) => void;
-    onInfo?: (infos: Info[]) => void;
+    onInfo?: (
+        x: number,
+        logController: LogViewer,
+        iFrom: number,
+        iTo: number
+    ) => void;
 
     onTrackScroll?: () => void; // called when track scrolling are changed
     onContentRescale?: () => void; // called when content zoom and scrolling are changed
 
-    onTrackMouseEvent?: (wellLogView: WellLogView, ev: TrackMouseEvent) => void;
+    onTrackMouseEvent?: (wellLogView: WellLogView, ev: TrackMouseEvent) => void; // called when mouse click on a track
+    onTemplateChanged?: () => void; // called when track scrolling are changed
 }
 
 interface State {
@@ -734,6 +615,8 @@ class WellLogView extends Component<Props, State> implements WellLogController {
     selPinned: number | undefined; // pinned position
     selPersistent: boolean | undefined;
 
+    template: Template;
+
     constructor(props: Props) {
         super(props);
 
@@ -744,9 +627,18 @@ class WellLogView extends Component<Props, State> implements WellLogController {
         this.selPinned = undefined;
         this.selPersistent = undefined;
 
+        this.template = {
+            name: "",
+            scale: {
+                primary: "",
+            },
+            tracks: [],
+            styles: [],
+        };
+
         this.state = {
             infos: [],
-            scrollTrackPos: props.scrollTrackPos ? props.scrollTrackPos : 0,
+            scrollTrackPos: 0,
         };
 
         this.onTrackMouseEvent = this.onTrackMouseEvent.bind(this);
@@ -759,6 +651,8 @@ class WellLogView extends Component<Props, State> implements WellLogController {
 
     componentDidMount(): void {
         this.createLogViewer();
+
+        this.template = JSON.parse(JSON.stringify(this.props.template)); // save external template content to current
         this.setTracks();
     }
     shouldComponentUpdate(nextProps: Props, nextState: State): boolean {
@@ -770,8 +664,8 @@ class WellLogView extends Component<Props, State> implements WellLogController {
         if (this.props.axisTitles !== nextProps.axisTitles) return true;
         if (this.props.axisMnemos !== nextProps.axisMnemos) return true;
 
-        if (this.props.maxTrackNum !== nextProps.maxTrackNum) return true;
-        if (this.props.scrollTrackPos !== nextProps.scrollTrackPos) return true;
+        if (this.props.maxVisibleTrackNum !== nextProps.maxVisibleTrackNum)
+            return true;
         if (this.state.scrollTrackPos !== nextState.scrollTrackPos) return true;
 
         if (this.props.maxContentZoom !== nextProps.maxContentZoom) return true;
@@ -788,11 +682,16 @@ class WellLogView extends Component<Props, State> implements WellLogController {
                 this.props.onCreateController(this);
         }
 
+        let selectedTrackIndeces: number[] = []; // indeces to restore
+        let selection: [number | undefined, number | undefined] | undefined =
+            undefined; // content selection to restore
         let shouldSetTracks = false;
         if (
             this.props.horizontal !== prevProps.horizontal ||
             this.props.maxContentZoom !== prevProps.maxContentZoom
         ) {
+            selection = this.getContentSelection();
+            selectedTrackIndeces = getSelectTrackIndeces(this.logController);
             this.createLogViewer();
             shouldSetTracks = true;
         }
@@ -800,27 +699,31 @@ class WellLogView extends Component<Props, State> implements WellLogController {
         if (this.props.welllog !== prevProps.welllog) {
             shouldSetTracks = true;
         } else if (this.props.template !== prevProps.template) {
+            this.template = JSON.parse(JSON.stringify(this.props.template)); // save external template content to current
             shouldSetTracks = true;
         } else if (this.props.colorTables !== prevProps.colorTables) {
+            selection = this.getContentSelection();
+            selectedTrackIndeces = getSelectTrackIndeces(this.logController);
             shouldSetTracks = true; // force to repaint
         } else if (this.props.primaryAxis !== prevProps.primaryAxis) {
+            selectedTrackIndeces = getSelectTrackIndeces(this.logController);
             shouldSetTracks = true;
         } else if (
             this.props.axisTitles !== prevProps.axisTitles ||
             this.props.axisMnemos !== prevProps.axisMnemos
         ) {
-            shouldSetTracks = true;
+            selection = this.getContentSelection();
+            selectedTrackIndeces = getSelectTrackIndeces(this.logController);
+            shouldSetTracks = true; //??
         }
 
         if (shouldSetTracks) {
-            this.setTracks();
-        } else if (this.props.scrollTrackPos !== prevProps.scrollTrackPos) {
-            this.scrollTrackTo(
-                this.props.scrollTrackPos ? this.props.scrollTrackPos : 0
-            );
+            this.setTracks(); // use this.template
+            restoreSelectTracks(this.logController, selectedTrackIndeces);
+            if (selection) this.selectContent(selection);
         } else if (
             this.state.scrollTrackPos !== prevState.scrollTrackPos ||
-            this.props.maxTrackNum !== prevProps.maxTrackNum
+            this.props.maxVisibleTrackNum !== prevProps.maxVisibleTrackNum
         ) {
             this.onTrackScroll();
             this.setInfo();
@@ -852,9 +755,7 @@ class WellLogView extends Component<Props, State> implements WellLogController {
 
             this.logController.init(this.container);
 
-            addReadoutOverlay(this.logController, this);
-            addRubberbandOverlay(this.logController, this);
-            addPinnedValueOverlay(this.logController, this);
+            initOverlay(this.logController, this);
         }
         this.setInfo();
     }
@@ -883,7 +784,7 @@ class WellLogView extends Component<Props, State> implements WellLogController {
                 this.logController,
                 axes,
                 this.props.welllog,
-                this.props.template,
+                this.template,
                 this.props.colorTables
             );
         }
@@ -891,28 +792,35 @@ class WellLogView extends Component<Props, State> implements WellLogController {
         this.setInfo(); // Clear old track information
     }
 
+    findTrackById(trackId: string | number): Track | undefined {
+        return this.logController?.tracks.find(function (track: Track) {
+            return track.id === trackId;
+        });
+    }
+
     /** 
       Display current state of track scrolling
       */
     onTrackScroll(): void {
         const iFrom = this.getTrackScrollPos();
-        const iTo = iFrom + this._maxTrackNum();
+        const iTo = iFrom + this._maxVisibleTrackNum();
         if (this.logController) scrollTracksTo(this.logController, iFrom, iTo);
 
         if (this.props.onTrackScroll) this.props.onTrackScroll();
     }
-    setInfo(x: number = Number.NaN, x2: number = Number.NaN): void {
+    setInfo(x: number = Number.NaN): void {
         if (!this.props.onInfo) return; // no callback is given
         if (!this.logController) return; // not initialized yet
 
+        if (isNaN(x) && this.selCurrent !== undefined) x = this.selCurrent;
+
         const iFrom = this.getTrackScrollPos();
-        const iTo = iFrom + this._maxTrackNum();
-        const infos = fillInfos(x, x2, this.logController.tracks, iFrom, iTo);
-        this.props.onInfo(infos);
+        const iTo = iFrom + this._maxVisibleTrackNum();
+        this.props.onInfo(x, this.logController, iFrom, iTo);
     }
 
-    onMouseMove(x: number, x2: number): void {
-        this.setInfo(x, x2);
+    onMouseMove(x: number): void {
+        this.setInfo(x);
 
         this.onContentRescale();
     }
@@ -931,6 +839,14 @@ class WellLogView extends Component<Props, State> implements WellLogController {
             this.props.onTrackMouseEvent(this, ev);
     }
 
+    onTemplateChanged(): void {
+        this.setInfo();
+
+        this.template = this._generateTemplate(); // save current template
+
+        if (this.props.onTemplateChanged) this.props.onTemplateChanged();
+    }
+
     // content
     zoomContentTo(domain: [number, number]): boolean {
         if (this.logController)
@@ -968,9 +884,10 @@ class WellLogView extends Component<Props, State> implements WellLogController {
     selectContent(selection: [number | undefined, number | undefined]): void {
         this.selCurrent = selection[0];
         this.selPinned = selection[1];
-        this.selPersistent = true;
+        this.selPersistent = this.selPinned ? true : false;
 
         this.showSelection();
+        this.setInfo(); // reflect new value in this.selCurrent
     }
     getContentBaseDomain(): [number, number] {
         if (this.logController) return getContentBaseDomain(this.logController);
@@ -1007,10 +924,10 @@ class WellLogView extends Component<Props, State> implements WellLogController {
         if (newPos < 0) newPos = 0;
         return newPos;
     }
-    _maxTrackNum(): number {
-        return this.props.maxTrackNum
-            ? this.props.maxTrackNum
-            : 6 /*some default value*/;
+    _maxVisibleTrackNum(): number {
+        return this.props.maxVisibleTrackNum
+            ? this.props.maxVisibleTrackNum
+            : 5 /*some default value*/;
     }
 
     scrollTrackBy(delta: number): void {
@@ -1033,45 +950,42 @@ class WellLogView extends Component<Props, State> implements WellLogController {
     getTrackScrollPosMax(): number {
         // for scrollbar
         const nGraphTracks = this._graphTrackMax();
-        let posMax = nGraphTracks - this._maxTrackNum();
+        let posMax = nGraphTracks - this._maxVisibleTrackNum();
         if (posMax < 0) posMax = 0;
         return posMax;
     }
     getTrackZoom(): number {
-        return this._graphTrackMax() / this._maxTrackNum();
+        return this._graphTrackMax() / this._maxVisibleTrackNum();
+    }
+
+    getTemplate(): Template {
+        return this.template;
+    }
+
+    _generateTemplate(): Template {
+        const template = this.template;
+        const tracks: TemplateTrack[] = [];
+        if (this.logController) {
+            for (const track of this.logController.tracks) {
+                if (isScaleTrack(track)) continue;
+                const templateTrack = getTrackTemplate(track);
+                tracks.push(JSON.parse(JSON.stringify(templateTrack)));
+            }
+        }
+        return {
+            name: template.name,
+            scale: {
+                primary: this.props.primaryAxis,
+                allowSecondary: template.scale?.allowSecondary,
+            },
+            tracks: tracks,
+            styles: template.styles,
+        };
     }
 
     // editting
-
-    __addTrack(trackNew: Track, trackCurrent: Track, bAfter: boolean): void {
-        if (this.logController) {
-            let order = 0;
-            for (const track of this.logController.tracks) {
-                track.order = order++;
-                if (trackCurrent == track) {
-                    if (bAfter) {
-                        // add after
-                        trackNew.order = order++;
-                    } else {
-                        // insert before current
-                        trackNew.order = track.order;
-                        track.order = order++;
-                    }
-                }
-            }
-
-            this.logController.addTrack(trackNew);
-            if (bAfter)
-                // force new track to be visible when added after the current
-                this.scrollTrackBy(+1);
-            else {
-                this.onTrackScroll();
-                this.setInfo();
-            }
-        }
-    }
-
     _addTrack(trackCurrent: Track, templateTrack: TemplateTrack): void {
+        templateTrack.required = true; // user's tracks could be empty
         const bAfter = true;
         const trackNew = addOrEditGraphTrack(
             this,
@@ -1080,6 +994,7 @@ class WellLogView extends Component<Props, State> implements WellLogController {
             trackCurrent,
             bAfter
         );
+        this.onTemplateChanged();
 
         if (bAfter)
             // force new track to be visible when added after the current
@@ -1099,7 +1014,7 @@ class WellLogView extends Component<Props, State> implements WellLogController {
             track,
             false
         );
-        this.setInfo();
+        this.onTemplateChanged();
     }
 
     removeTrack(track: Track): void {
@@ -1107,7 +1022,7 @@ class WellLogView extends Component<Props, State> implements WellLogController {
             this.logController.removeTrack(track);
 
             this.onTrackScroll();
-            this.setInfo();
+            this.onTemplateChanged();
         }
     }
 
@@ -1131,31 +1046,66 @@ class WellLogView extends Component<Props, State> implements WellLogController {
 
     addTrackPlot(track: Track, templatePlot: TemplatePlot): void {
         addOrEditGraphTrackPlot(this, track as GraphTrack, null, templatePlot);
-        this.setInfo();
+        this.onTemplateChanged();
     }
 
-    _editTrackPlot(track: Track, plot: Plot, templatePlot: TemplatePlot): void {
+    _editTrackPlot(
+        track: Track,
+        plot: Plot,
+        _templatePlot: TemplatePlot
+    ): void {
+        const templatePlot = { ..._templatePlot };
+        /* We have special option for track scale!
+        const templateTrack = getTrackTemplate(track);
+        if (templatePlot.scale === templateTrack.scale)
+            templatePlot.scale = undefined;
+        */
+
         addOrEditGraphTrackPlot(this, track as GraphTrack, plot, templatePlot);
-        this.setInfo();
+        this.onTemplateChanged();
     }
 
     removeTrackPlot(track: Track, plot: Plot): void {
         removeGraphTrackPlot(this, track as GraphTrack, plot);
-        this.setInfo();
+        const templateTrack = getTrackTemplate(track);
+        templateTrack.required = true; // user's tracks could be empty
+        this.onTemplateChanged();
     }
 
     // Dialog functions
     addTrack(parent: HTMLElement | null, trackCurrent: Track): void {
-        if (parent) addTrack(parent, this, trackCurrent);
+        if (parent) {
+            addTrack(parent, this, this._addTrack.bind(this, trackCurrent));
+        }
     }
     editTrack(parent: HTMLElement | null, track: Track): void {
-        if (parent) editTrack(parent, this, track);
+        if (parent) {
+            const templateTrack = getTrackTemplate(track);
+            editTrack(
+                parent,
+                this,
+                templateTrack,
+                this._editTrack.bind(this, track)
+            );
+        }
     }
     addPlot(parent: HTMLElement | null, track: Track): void {
-        if (parent) addPlot(parent, this, track);
+        if (parent) {
+            addPlot(parent, this, track);
+        }
     }
     editPlot(parent: HTMLElement | null, track: Track, plot: Plot): void {
-        if (parent) editPlot(parent, this, track, plot);
+        if (parent) {
+            const templateTrack = getTrackTemplate(track);
+            const templatePlot = fillPlotTemplate(templateTrack, plot);
+            editPlot(
+                parent,
+                this,
+                track,
+                templatePlot,
+                this._editTrackPlot.bind(this, track, plot)
+            );
+        }
     }
 
     render(): ReactNode {
