@@ -6,8 +6,10 @@ from .LeafletMap import LeafletMap
 from .Map import Map
 from .Morris import Morris
 from .PriorPosteriorDistribution import PriorPosteriorDistribution
+from .VectorCalculator import VectorCalculator
 from .VectorSelector import VectorSelector
 from .WellCompletions import WellCompletions
+from .WellLogViewer import WellLogViewer
 
 __all__ = [
     "DeckGLMap",
@@ -18,6 +20,8 @@ __all__ = [
     "Map",
     "Morris",
     "PriorPosteriorDistribution",
+    "VectorCalculator",
     "VectorSelector",
-    "WellCompletions"
+    "WellCompletions",
+    "WellLogViewer"
 ]
\ No newline at end of file
